@@ -47,7 +47,7 @@ def filename_only(para_combination):
 
 
 def path_reference_code(save_name):
-    reference_code = str(zlib.crc32(bytes(save_name, 'UTF-8')))[:6]
+    reference_code = str(zlib.crc32(bytes(save_name, 'UTF-8')))[:8]
     return reference_code
 
 
@@ -206,16 +206,10 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
         para_combination['risk_free_rate'] = risk_free_rate
         cal_performance_list.append((para_combination, manager_list))
 
-    a = datetime.datetime.now()
-
     pool = mp.Pool(processes=number_of_core)
     pool.map(mp_cal_performance, cal_performance_list)
     pool.close()
 
-    b = datetime.datetime.now()
-    t = b - a
-    print('Process time:', t.total_seconds(), 's')
-
     pd.DataFrame(list(manager_list)).to_csv('backtest_result.csv')
 
 
