@@ -240,11 +240,15 @@ class Aggregate:
                 df_csv['date'] = pd.to_datetime(df_csv['date'], format='%Y-%m-%d')
                 df_csv = df_csv.set_index('date')
 
+                # print(df_csv)
+
                 if (intraday or summary):
                     df = plotguy.resample_summary_to_daily(para_combination=para_combination[i],folder=folders[i])
                 else:
                     df = df_csv
 
+                df = df.set_index('date')
+
                 df_current = pd.DataFrame()
                 if normalized_boolean:
                     df_current[f'{folders[i]}_{pys[i]}_{i}'] = df['equity_value'] / (df['equity_value'].iloc[0] / 100000)
@@ -330,6 +334,7 @@ class Aggregate:
 
             start_date_year = df_all_curves.loc[df_all_curves.index[0], 'date'].year
             end_date_year = df_all_curves.loc[df_all_curves.index[-1], 'date'].year
+
             year_list = list(range(start_date_year, end_date_year + 1))
 
 
