@@ -76,7 +76,7 @@ class Components:
                        value=f'Top Net Profit',
                        options=[{'label': f'Top {number_of_curves} Net Profit', 'value': 'Top Net Profit'},
                                 {'label': f'Top {number_of_curves} Return-BaH % Difference', 'value': 'Top Return to BaH Ratio'},
-                                {'label': f'Top {number_of_curves} Net Profit/MDD', 'value': 'Top Net Profit to MDD'}, ],
+                                {'label': f'Top {number_of_curves} Sharp Ratio', 'value': 'Top Sharp Ratio'}, ],
                        style={'border-radius': '5px', 'font-size': '12px', }),
             style={'padding-left': '15px', 'width': '235px'})
 
@@ -433,8 +433,8 @@ class Components:
     def sort_method_df(self, sort_method, result_df, number_of_curves):
         if sort_method == 'Top Net Profit':
             df_sorted = result_df.sort_values(by='net_profit', ascending=False).head(number_of_curves).copy()
-        elif sort_method == 'Top Net Profit to MDD':
-            df_sorted = result_df.sort_values(by='net_profit_to_mdd', ascending=False).head(number_of_curves).copy()
+        elif sort_method == 'Top Sharp Ratio':
+            df_sorted = result_df.sort_values(by='annualized_sr', ascending=False).head(number_of_curves).copy()
         elif sort_method == 'Top Return to BaH Ratio':
             df_sorted = result_df.sort_values(by='return_to_bah', ascending=False).head(number_of_curves).copy()
         else:
@@ -743,11 +743,13 @@ class Components:
         else:
             df_backtest = pd.read_csv(save_path, index_col=0)  # Daraframe that may not be daily
 
+
         df_csv = df_backtest.copy()
         df_chart = self.prepare_df_chart(df_csv)
 
         df_signal = df_chart.copy()
-        df_signal = df_signal.dropna(subset=['action'])
+        df_signal = df_signal.dropna(subset=['action'])  # for csv
+        df_signal = df_signal.loc[df_signal['action'] != '']  # for parquet
         df_signal = df_signal.reset_index()
         signal_open_date = []
         signal_open_close = []
@@ -810,8 +812,10 @@ class Components:
         df_signal_final['close_date'] = close_date
         df_signal_final['close_close'] = close_close
         df_signal_final['close_reason'] = close_reason
-        df_signal_final['pctchange'] = ((df_signal_final['close_close'] - df_signal_final['open_close']) /
-                                        df_signal_final['open_close']) * 100
+        df_signal_final['pctchange'] = (((df_signal_final['close_close'] - df_signal_final['open_close']) /
+                                        df_signal_final['open_close']) * 100)
+
+
         df_signal_final.open_close = df_signal_final.open_close.round(2)
         df_signal_final.close_close = df_signal_final.close_close.round(2)
         df_signal_final.pctchange = df_signal_final.pctchange.round(2)
@@ -831,6 +835,8 @@ class Components:
         title = ''
         para_dict = para_combination['para_dict']
         for key in para_dict:
+            if len(title) > 100:
+                title = title + '<br>'
             title = title + f'{key}:{para_combination[key]} '
 
         # Count number of subchart
@@ -851,7 +857,7 @@ class Components:
         fig_line = make_subplots(rows=subchart_count+1, cols=1,
                                  row_heights=row_height,shared_xaxes=True)
 
-        fig_line.update_layout(title = {'text': title , 'font': {'size': 12 }  })
+        fig_line.update_layout(title = {'text': title , 'font': {'size': 12 }, 'y':0.97,  })
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.add_trace(go.Scatter(mode='lines', hoverinfo='skip',
@@ -1034,17 +1040,34 @@ class Components:
                 equity_path = f'{folder}/{row["path"]}'
 
                 dict = {}
+                # parameters = ast.literal_eval(row['para_combination'])
                 dict['para_combination'] = ast.literal_eval(row['para_combination'])
-                para_combination = dict['para_combination']
+                para_combination = ast.literal_eval(row['para_combination'])
+                dict['para_combination'] = para_combination
                 file_format = para_combination['file_format']
                 save_name = plotguy.filename_only(para_combination)
                 ref_code = plotguy.path_reference_code(save_name)
-                parameters = self.path_to_dict(equity_path, file_format )
+
+
+                # parameters = self.path_to_dict(equity_path, file_format)
+                parameters = {}
+                for element in save_name.split('&')[:-1]:
+                    key, content = element.split('=')
+                    if key == 'date':
+                        # parameters['date'] = f'{content[:8]} - {content[8:]}'
+                        parameters['startdate'], parameters['enddate'] = content[:8], content[8:]
+                    elif key == 'summary_mode':
+                        pass
+                    else:
+                        parameters[key] = content
 
                 dict['folder'] = folder
                 dict['py'] = parameters['file']
                 dict['path'] = equity_path
                 dict['parameters'] = parameters
+
+
+
                 dict['performance'] = {
                     'initial_capital': row['initial'],
                     'net_profit_to_mdd': row['net_profit_to_mdd'],
@@ -1060,8 +1083,10 @@ class Components:
                 dict['format'] = file_format
                 dict['ref'] = ref_code
 
+
                 start_date_year = datetime.datetime.strptime(parameters['startdate'], '%Y%m%d').year
                 end_date_year = datetime.datetime.strptime(parameters['enddate'], '%Y%m%d').year
+
                 year_list = list(range(start_date_year, end_date_year + 1))
                 for year in year_list:
                     dict['performance'][f'{year}'] = row[f'{year}']
@@ -1270,6 +1295,7 @@ class Components:
         year_count_col = []
         year_win_rate_col = []
         year_return_col = []
+
         for year in year_list:
             year_col.append(html.Div(year))
             year_count.append(int(total_dict[f'{year}']))
